Getting help
------------

.. include:: ../../../README.rst
   :start-after: Start support description
   :end-before: End support description

.. _space on Matrix: https://matrix.to/#/#aiida-vasp:matrix.org
.. _AiiDA-VASP documentation: https://aiida-vasp.readthedocs.io/en/latest/
.. _AiiDA documentation: http://aiida-core.readthedocs.io/en/latest/
